@@ -41,6 +41,7 @@
 #include "lib/jxl/encode_internal.h"
 #include "lib/jxl/modular/options.h"
 #include "lib/jxl/test_image.h"
+#include "lib/jxl/test_memory_manager.h"
 #include "lib/jxl/test_utils.h"
 #include "lib/jxl/testing.h"
 
@@ -80,16 +81,16 @@ TEST(EncodeTest, AddFrameAfterCloseInputTest) {
   jxl::test::JxlBasicInfoSetFromPixelFormat(&basic_info, &pixel_format);
   basic_info.xsize = xsize;
   basic_info.ysize = ysize;
-  basic_info.uses_original_profile = false;
+  basic_info.uses_original_profile = 0;
   EXPECT_EQ(JXL_ENC_SUCCESS, JxlEncoderSetCodestreamLevel(enc.get(), 10));
   EXPECT_EQ(JXL_ENC_SUCCESS, JxlEncoderSetBasicInfo(enc.get(), &basic_info));
   JxlColorEncoding color_encoding;
-  JxlColorEncodingSetToSRGB(&color_encoding,
-                            /*is_gray=*/pixel_format.num_channels < 3);
+  JXL_BOOL is_gray = TO_JXL_BOOL(pixel_format.num_channels < 3);
+  JxlColorEncodingSetToSRGB(&color_encoding, is_gray);
   EXPECT_EQ(JXL_ENC_SUCCESS,
             JxlEncoderSetColorEncoding(enc.get(), &color_encoding));
   JxlEncoderFrameSettings* frame_settings =
-      JxlEncoderFrameSettingsCreate(enc.get(), NULL);
+      JxlEncoderFrameSettingsCreate(enc.get(), nullptr);
   EXPECT_EQ(JXL_ENC_ERROR,
             JxlEncoderAddImageFrame(frame_settings, &pixel_format,
                                     pixels.data(), pixels.size()));
@@ -105,7 +106,7 @@ TEST(EncodeTest, AddJPEGAfterCloseTest) {
   const std::vector<uint8_t> orig = jxl::test::ReadTestData(jpeg_path);
 
   JxlEncoderFrameSettings* frame_settings =
-      JxlEncoderFrameSettingsCreate(enc.get(), NULL);
+      JxlEncoderFrameSettingsCreate(enc.get(), nullptr);
 
   EXPECT_EQ(JXL_ENC_ERROR,
             JxlEncoderAddJPEGFrame(frame_settings, orig.data(), orig.size()));
@@ -124,12 +125,12 @@ TEST(EncodeTest, AddFrameBeforeBasicInfoTest) {
       jxl::test::SomeTestImageToCodecInOut(pixels, 4, xsize, ysize);
 
   JxlColorEncoding color_encoding;
-  JxlColorEncodingSetToSRGB(&color_encoding,
-                            /*is_gray=*/pixel_format.num_channels < 3);
+  JXL_BOOL is_gray = TO_JXL_BOOL(pixel_format.num_channels < 3);
+  JxlColorEncodingSetToSRGB(&color_encoding, is_gray);
   EXPECT_EQ(JXL_ENC_ERROR,
             JxlEncoderSetColorEncoding(enc.get(), &color_encoding));
   JxlEncoderFrameSettings* frame_settings =
-      JxlEncoderFrameSettingsCreate(enc.get(), NULL);
+      JxlEncoderFrameSettingsCreate(enc.get(), nullptr);
   EXPECT_EQ(JXL_ENC_ERROR,
             JxlEncoderAddImageFrame(frame_settings, &pixel_format,
                                     pixels.data(), pixels.size()));
@@ -189,17 +190,17 @@ void VerifyFrameEncoding(size_t xsize, size_t ysize, JxlEncoder* enc,
   basic_info.xsize = xsize;
   basic_info.ysize = ysize;
   if (frame_settings->values.lossless || lossy_use_original_profile) {
-    basic_info.uses_original_profile = true;
+    basic_info.uses_original_profile = JXL_TRUE;
   } else {
-    basic_info.uses_original_profile = false;
+    basic_info.uses_original_profile = JXL_FALSE;
   }
   // 16-bit alpha means this requires level 10
   EXPECT_EQ(JXL_ENC_SUCCESS, JxlEncoderSetCodestreamLevel(enc, 10));
   EXPECT_EQ(JXL_ENC_SUCCESS, JxlEncoderSetBasicInfo(enc, &basic_info));
   JxlColorEncoding color_encoding;
-  JxlColorEncodingSetToSRGB(&color_encoding, true);
+  JxlColorEncodingSetToSRGB(&color_encoding, JXL_TRUE);
   EXPECT_EQ(JXL_ENC_ERROR, JxlEncoderSetColorEncoding(enc, &color_encoding));
-  JxlColorEncodingSetToSRGB(&color_encoding, false);
+  JxlColorEncodingSetToSRGB(&color_encoding, JXL_FALSE);
   EXPECT_EQ(JXL_ENC_SUCCESS, JxlEncoderSetColorEncoding(enc, &color_encoding));
   pixel_format.num_channels = 1;
   EXPECT_EQ(JXL_ENC_ERROR,
@@ -227,13 +228,13 @@ void VerifyFrameEncoding(size_t xsize, size_t ysize, JxlEncoder* enc,
   compressed.resize(next_out - compressed.data());
   EXPECT_LE(compressed.size(), max_compressed_size);
   EXPECT_EQ(JXL_ENC_SUCCESS, process_result);
-  jxl::CodecInOut decoded_io;
+  jxl::CodecInOut decoded_io{jxl::test::MemoryManager()};
   EXPECT_TRUE(jxl::test::DecodeFile(
       {}, jxl::Bytes(compressed.data(), compressed.size()), &decoded_io));
 
   static constexpr double kMaxButteraugli =
 #if JXL_HIGH_PRECISION
-      1.84;
+      3.2;
 #else
       8.7;
 #endif
@@ -259,7 +260,7 @@ TEST(EncodeTest, EncoderResetTest) {
   JxlEncoderPtr enc = JxlEncoderMake(nullptr);
   EXPECT_NE(nullptr, enc.get());
   VerifyFrameEncoding(50, 200, enc.get(),
-                      JxlEncoderFrameSettingsCreate(enc.get(), nullptr), 4550,
+                      JxlEncoderFrameSettingsCreate(enc.get(), nullptr), 4599,
                       false);
   // Encoder should become reusable for a new image from scratch after using
   // reset.
@@ -296,7 +297,7 @@ TEST(EncodeTest, CmsTest) {
   JxlEncoderSetCms(enc.get(), cms);
   JxlEncoderFrameSettings* frame_settings =
       JxlEncoderFrameSettingsCreate(enc.get(), nullptr);
-  JxlEncoderSetFrameLossless(frame_settings, false);
+  JxlEncoderSetFrameLossless(frame_settings, JXL_FALSE);
   ASSERT_EQ(JXL_ENC_SUCCESS,
             JxlEncoderFrameSettingsSetOption(frame_settings,
                                              JXL_ENC_FRAME_SETTING_EFFORT, 8));
@@ -304,12 +305,12 @@ TEST(EncodeTest, CmsTest) {
   EXPECT_TRUE(cms_called);
 }
 
-TEST(EncodeTest, frame_settingsTest) {
+TEST(EncodeTest, FrameSettingsTest) {
   {
     JxlEncoderPtr enc = JxlEncoderMake(nullptr);
     EXPECT_NE(nullptr, enc.get());
     JxlEncoderFrameSettings* frame_settings =
-        JxlEncoderFrameSettingsCreate(enc.get(), NULL);
+        JxlEncoderFrameSettingsCreate(enc.get(), nullptr);
     EXPECT_EQ(JXL_ENC_SUCCESS,
               JxlEncoderFrameSettingsSetOption(
                   frame_settings, JXL_ENC_FRAME_SETTING_EFFORT, 5));
@@ -321,7 +322,7 @@ TEST(EncodeTest, frame_settingsTest) {
     JxlEncoderPtr enc = JxlEncoderMake(nullptr);
     EXPECT_NE(nullptr, enc.get());
     JxlEncoderFrameSettings* frame_settings =
-        JxlEncoderFrameSettingsCreate(enc.get(), NULL);
+        JxlEncoderFrameSettingsCreate(enc.get(), nullptr);
     const size_t nb_options = 23;
     const JxlEncoderFrameSettingId options[nb_options] = {
         JXL_ENC_FRAME_SETTING_EFFORT,
@@ -448,10 +449,10 @@ TEST(EncodeTest, frame_settingsTest) {
     JxlEncoderPtr enc = JxlEncoderMake(nullptr);
     EXPECT_NE(nullptr, enc.get());
     JxlEncoderFrameSettings* frame_settings =
-        JxlEncoderFrameSettingsCreate(enc.get(), NULL);
+        JxlEncoderFrameSettingsCreate(enc.get(), nullptr);
     EXPECT_EQ(JXL_ENC_SUCCESS,
               JxlEncoderSetFrameLossless(frame_settings, JXL_TRUE));
-    VerifyFrameEncoding(63, 129, enc.get(), frame_settings, 3000, false);
+    VerifyFrameEncoding(63, 129, enc.get(), frame_settings, 3600, false);
     EXPECT_EQ(true, enc->last_used_cparams.IsLossless());
   }
 
@@ -459,16 +460,16 @@ TEST(EncodeTest, frame_settingsTest) {
     JxlEncoderPtr enc = JxlEncoderMake(nullptr);
     EXPECT_NE(nullptr, enc.get());
     JxlEncoderFrameSettings* frame_settings =
-        JxlEncoderFrameSettingsCreate(enc.get(), NULL);
+        JxlEncoderFrameSettingsCreate(enc.get(), nullptr);
     EXPECT_EQ(JXL_ENC_SUCCESS, JxlEncoderSetFrameDistance(frame_settings, 0.5));
-    VerifyFrameEncoding(63, 129, enc.get(), frame_settings, 3130, false);
+    VerifyFrameEncoding(63, 129, enc.get(), frame_settings, 3200, false);
     EXPECT_EQ(0.5, enc->last_used_cparams.butteraugli_distance);
   }
 
   {
     JxlEncoderPtr enc = JxlEncoderMake(nullptr);
     JxlEncoderFrameSettings* frame_settings =
-        JxlEncoderFrameSettingsCreate(enc.get(), NULL);
+        JxlEncoderFrameSettingsCreate(enc.get(), nullptr);
     // Disallowed negative distance
     EXPECT_EQ(JXL_ENC_ERROR, JxlEncoderSetFrameDistance(frame_settings, -1));
   }
@@ -477,7 +478,7 @@ TEST(EncodeTest, frame_settingsTest) {
     JxlEncoderPtr enc = JxlEncoderMake(nullptr);
     EXPECT_NE(nullptr, enc.get());
     JxlEncoderFrameSettings* frame_settings =
-        JxlEncoderFrameSettingsCreate(enc.get(), NULL);
+        JxlEncoderFrameSettingsCreate(enc.get(), nullptr);
     EXPECT_EQ(JXL_ENC_SUCCESS,
               JxlEncoderFrameSettingsSetOption(
                   frame_settings, JXL_ENC_FRAME_SETTING_DECODING_SPEED, 2));
@@ -489,7 +490,7 @@ TEST(EncodeTest, frame_settingsTest) {
     JxlEncoderPtr enc = JxlEncoderMake(nullptr);
     EXPECT_NE(nullptr, enc.get());
     JxlEncoderFrameSettings* frame_settings =
-        JxlEncoderFrameSettingsCreate(enc.get(), NULL);
+        JxlEncoderFrameSettingsCreate(enc.get(), nullptr);
     EXPECT_EQ(JXL_ENC_ERROR,
               JxlEncoderFrameSettingsSetOption(
                   frame_settings, JXL_ENC_FRAME_SETTING_GROUP_ORDER, 100));
@@ -509,7 +510,7 @@ TEST(EncodeTest, frame_settingsTest) {
     JxlEncoderPtr enc = JxlEncoderMake(nullptr);
     EXPECT_NE(nullptr, enc.get());
     JxlEncoderFrameSettings* frame_settings =
-        JxlEncoderFrameSettingsCreate(enc.get(), NULL);
+        JxlEncoderFrameSettingsCreate(enc.get(), nullptr);
     EXPECT_EQ(JXL_ENC_SUCCESS,
               JxlEncoderFrameSettingsSetOption(
                   frame_settings, JXL_ENC_FRAME_SETTING_RESPONSIVE, 0));
@@ -533,7 +534,7 @@ TEST(EncodeTest, frame_settingsTest) {
     JxlEncoderPtr enc = JxlEncoderMake(nullptr);
     EXPECT_NE(nullptr, enc.get());
     JxlEncoderFrameSettings* frame_settings =
-        JxlEncoderFrameSettingsCreate(enc.get(), NULL);
+        JxlEncoderFrameSettingsCreate(enc.get(), nullptr);
     EXPECT_EQ(
         JXL_ENC_SUCCESS,
         JxlEncoderFrameSettingsSetFloatOption(
@@ -546,7 +547,7 @@ TEST(EncodeTest, frame_settingsTest) {
     JxlEncoderPtr enc = JxlEncoderMake(nullptr);
     EXPECT_NE(nullptr, enc.get());
     JxlEncoderFrameSettings* frame_settings =
-        JxlEncoderFrameSettingsCreate(enc.get(), NULL);
+        JxlEncoderFrameSettingsCreate(enc.get(), nullptr);
     EXPECT_EQ(JXL_ENC_SUCCESS,
               JxlEncoderFrameSettingsSetFloatOption(
                   frame_settings,
@@ -574,7 +575,7 @@ TEST(EncodeTest, frame_settingsTest) {
     JxlEncoderPtr enc = JxlEncoderMake(nullptr);
     EXPECT_NE(nullptr, enc.get());
     JxlEncoderFrameSettings* frame_settings =
-        JxlEncoderFrameSettingsCreate(enc.get(), NULL);
+        JxlEncoderFrameSettingsCreate(enc.get(), nullptr);
     EXPECT_EQ(
         JXL_ENC_SUCCESS,
         JxlEncoderFrameSettingsSetOption(
@@ -606,7 +607,7 @@ TEST(EncodeTest, frame_settingsTest) {
     JxlEncoderPtr enc = JxlEncoderMake(nullptr);
     EXPECT_NE(nullptr, enc.get());
     JxlEncoderFrameSettings* frame_settings =
-        JxlEncoderFrameSettingsCreate(enc.get(), NULL);
+        JxlEncoderFrameSettingsCreate(enc.get(), nullptr);
     EXPECT_EQ(JXL_ENC_SUCCESS,
               JxlEncoderFrameSettingsSetOption(
                   frame_settings, JXL_ENC_FRAME_SETTING_JPEG_RECON_CFL, 0));
@@ -618,7 +619,7 @@ TEST(EncodeTest, frame_settingsTest) {
     JxlEncoderPtr enc = JxlEncoderMake(nullptr);
     EXPECT_NE(nullptr, enc.get());
     JxlEncoderFrameSettings* frame_settings =
-        JxlEncoderFrameSettingsCreate(enc.get(), NULL);
+        JxlEncoderFrameSettingsCreate(enc.get(), nullptr);
     EXPECT_EQ(JXL_ENC_SUCCESS,
               JxlEncoderFrameSettingsSetOption(
                   frame_settings, JXL_ENC_FRAME_SETTING_JPEG_RECON_CFL, 1));
@@ -632,14 +633,14 @@ TEST(EncodeTest, LossyEncoderUseOriginalProfileTest) {
     JxlEncoderPtr enc = JxlEncoderMake(nullptr);
     ASSERT_NE(nullptr, enc.get());
     JxlEncoderFrameSettings* frame_settings =
-        JxlEncoderFrameSettingsCreate(enc.get(), NULL);
+        JxlEncoderFrameSettingsCreate(enc.get(), nullptr);
     VerifyFrameEncoding(63, 129, enc.get(), frame_settings, 7897, true);
   }
   {
     JxlEncoderPtr enc = JxlEncoderMake(nullptr);
     ASSERT_NE(nullptr, enc.get());
     JxlEncoderFrameSettings* frame_settings =
-        JxlEncoderFrameSettingsCreate(enc.get(), NULL);
+        JxlEncoderFrameSettingsCreate(enc.get(), nullptr);
     EXPECT_EQ(JXL_ENC_SUCCESS,
               JxlEncoderFrameSettingsSetOption(
                   frame_settings, JXL_ENC_FRAME_SETTING_PROGRESSIVE_DC, 2));
@@ -649,7 +650,7 @@ TEST(EncodeTest, LossyEncoderUseOriginalProfileTest) {
     JxlEncoderPtr enc = JxlEncoderMake(nullptr);
     ASSERT_NE(nullptr, enc.get());
     JxlEncoderFrameSettings* frame_settings =
-        JxlEncoderFrameSettingsCreate(enc.get(), NULL);
+        JxlEncoderFrameSettingsCreate(enc.get(), nullptr);
     ASSERT_EQ(JXL_ENC_SUCCESS,
               JxlEncoderFrameSettingsSetOption(
                   frame_settings, JXL_ENC_FRAME_SETTING_EFFORT, 8));
@@ -790,7 +791,7 @@ TEST(EncodeTest, SingleFrameBoundedJXLCTest) {
   EXPECT_NE(nullptr, enc.get());
   EXPECT_EQ(JXL_ENC_SUCCESS, JxlEncoderUseContainer(enc.get(), true));
   JxlEncoderFrameSettings* frame_settings =
-      JxlEncoderFrameSettingsCreate(enc.get(), NULL);
+      JxlEncoderFrameSettingsCreate(enc.get(), nullptr);
 
   size_t xsize = 71;
   size_t ysize = 23;
@@ -801,12 +802,12 @@ TEST(EncodeTest, SingleFrameBoundedJXLCTest) {
   jxl::test::JxlBasicInfoSetFromPixelFormat(&basic_info, &pixel_format);
   basic_info.xsize = xsize;
   basic_info.ysize = ysize;
-  basic_info.uses_original_profile = false;
+  basic_info.uses_original_profile = JXL_FALSE;
   EXPECT_EQ(JXL_ENC_SUCCESS, JxlEncoderSetCodestreamLevel(enc.get(), 10));
   EXPECT_EQ(JXL_ENC_SUCCESS, JxlEncoderSetBasicInfo(enc.get(), &basic_info));
   JxlColorEncoding color_encoding;
   JxlColorEncodingSetToSRGB(&color_encoding,
-                            /*is_gray=*/false);
+                            /*is_gray=*/JXL_FALSE);
   EXPECT_EQ(JXL_ENC_SUCCESS,
             JxlEncoderSetColorEncoding(enc.get(), &color_encoding));
   EXPECT_EQ(JXL_ENC_SUCCESS,
@@ -838,20 +839,20 @@ TEST(EncodeTest, SingleFrameBoundedJXLCTest) {
   bool found_jxlc = false;
   bool found_jxlp = false;
   // The encoder is allowed to either emit a jxlc or one or more jxlp.
-  for (size_t i = 0; i < container.boxes.size(); ++i) {
-    if (memcmp("jxlc", container.boxes[i].type, 4) == 0) {
+  for (const auto& box : container.boxes) {
+    if (memcmp("jxlc", box.type, 4) == 0) {
       EXPECT_EQ(false, found_jxlc);  // Max 1 jxlc
       EXPECT_EQ(false, found_jxlp);  // Can't mix jxlc and jxlp
       found_jxlc = true;
     }
-    if (memcmp("jxlp", container.boxes[i].type, 4) == 0) {
+    if (memcmp("jxlp", box.type, 4) == 0) {
       EXPECT_EQ(false, found_jxlc);  // Can't mix jxlc and jxlp
       found_jxlp = true;
     }
     // The encoder shouldn't create an unbounded box in this case, with the
     // single frame it knows the full size in time, so can help make decoding
     // more efficient by giving the full box size of the final box.
-    EXPECT_EQ(true, container.boxes[i].data_size_given);
+    EXPECT_EQ(true, box.data_size_given);
   }
   EXPECT_EQ(true, found_jxlc || found_jxlp);
 }
@@ -869,17 +870,17 @@ TEST(EncodeTest, CodestreamLevelTest) {
   jxl::test::JxlBasicInfoSetFromPixelFormat(&basic_info, &pixel_format);
   basic_info.xsize = xsize;
   basic_info.ysize = ysize;
-  basic_info.uses_original_profile = false;
+  basic_info.uses_original_profile = 0;
 
   JxlEncoderPtr enc = JxlEncoderMake(nullptr);
   EXPECT_EQ(JXL_ENC_SUCCESS, JxlEncoderSetCodestreamLevel(enc.get(), 10));
   JxlEncoderFrameSettings* frame_settings =
-      JxlEncoderFrameSettingsCreate(enc.get(), NULL);
+      JxlEncoderFrameSettingsCreate(enc.get(), nullptr);
 
   EXPECT_EQ(JXL_ENC_SUCCESS, JxlEncoderSetBasicInfo(enc.get(), &basic_info));
   JxlColorEncoding color_encoding;
-  JxlColorEncodingSetToSRGB(&color_encoding,
-                            /*is_gray=*/pixel_format.num_channels < 3);
+  JXL_BOOL is_gray = TO_JXL_BOOL(pixel_format.num_channels < 3);
+  JxlColorEncodingSetToSRGB(&color_encoding, is_gray);
   EXPECT_EQ(JXL_ENC_SUCCESS,
             JxlEncoderSetColorEncoding(enc.get(), &color_encoding));
   EXPECT_EQ(JXL_ENC_SUCCESS,
@@ -918,7 +919,7 @@ TEST(EncodeTest, CodestreamLevelVerificationTest) {
   jxl::test::JxlBasicInfoSetFromPixelFormat(&basic_info, &pixel_format);
   basic_info.xsize = 64;
   basic_info.ysize = 64;
-  basic_info.uses_original_profile = false;
+  basic_info.uses_original_profile = JXL_FALSE;
 
   JxlEncoderPtr enc = JxlEncoderMake(nullptr);
   EXPECT_EQ(JXL_ENC_SUCCESS, JxlEncoderSetBasicInfo(enc.get(), &basic_info));
@@ -940,13 +941,13 @@ TEST(EncodeTest, CodestreamLevelVerificationTest) {
   EXPECT_EQ(JXL_ENC_ERROR, JxlEncoderSetBasicInfo(enc.get(), &basic_info));
 }
 
-TEST(EncodeTest, JXL_TRANSCODE_JPEG_TEST(JPEGReconstructionTest)) {
+JXL_TRANSCODE_JPEG_TEST(EncodeTest, JPEGReconstructionTest) {
   const std::string jpeg_path = "jxl/flower/flower.png.im_q85_420.jpg";
   const std::vector<uint8_t> orig = jxl::test::ReadTestData(jpeg_path);
 
   JxlEncoderPtr enc = JxlEncoderMake(nullptr);
   JxlEncoderFrameSettings* frame_settings =
-      JxlEncoderFrameSettingsCreate(enc.get(), NULL);
+      JxlEncoderFrameSettingsCreate(enc.get(), nullptr);
 
   EXPECT_EQ(JXL_ENC_SUCCESS, JxlEncoderStoreJPEGMetadata(enc.get(), JXL_TRUE));
   EXPECT_EQ(JXL_ENC_SUCCESS,
@@ -980,13 +981,13 @@ TEST(EncodeTest, JXL_TRANSCODE_JPEG_TEST(JPEGReconstructionTest)) {
   EXPECT_EQ(0, memcmp(decoded_jpeg_bytes.data(), orig.data(), orig.size()));
 }
 
-TEST(EncodeTest, JXL_TRANSCODE_JPEG_TEST(ProgressiveJPEGReconstructionTest)) {
+JXL_TRANSCODE_JPEG_TEST(EncodeTest, ProgressiveJPEGReconstructionTest) {
   const std::string jpeg_path = "jxl/flower/flower.png.im_q85_420.jpg";
   const std::vector<uint8_t> orig = jxl::test::ReadTestData(jpeg_path);
 
   JxlEncoderPtr enc = JxlEncoderMake(nullptr);
   JxlEncoderFrameSettings* frame_settings =
-      JxlEncoderFrameSettingsCreate(enc.get(), NULL);
+      JxlEncoderFrameSettingsCreate(enc.get(), nullptr);
 
   frame_settings->values.cparams.progressive_mode = jxl::Override::kOn;
 
@@ -1046,7 +1047,7 @@ TEST(EncodeTest, BasicInfoTest) {
   EXPECT_NE(nullptr, enc.get());
 
   JxlEncoderFrameSettings* frame_settings =
-      JxlEncoderFrameSettingsCreate(enc.get(), NULL);
+      JxlEncoderFrameSettingsCreate(enc.get(), nullptr);
   size_t xsize = 1;
   size_t ysize = 1;
   JxlPixelFormat pixel_format = {4, JXL_TYPE_UINT16, JXL_BIG_ENDIAN, 0};
@@ -1055,8 +1056,8 @@ TEST(EncodeTest, BasicInfoTest) {
   jxl::test::JxlBasicInfoSetFromPixelFormat(&basic_info, &pixel_format);
   basic_info.xsize = xsize;
   basic_info.ysize = ysize;
-  basic_info.uses_original_profile = false;
-  basic_info.have_animation = true;
+  basic_info.uses_original_profile = 0;
+  basic_info.have_animation = 1;
   basic_info.intensity_target = 123.4;
   basic_info.min_nits = 5.0;
   basic_info.linear_below = 12.7;
@@ -1070,7 +1071,7 @@ TEST(EncodeTest, BasicInfoTest) {
   EXPECT_EQ(JXL_ENC_SUCCESS, JxlEncoderSetCodestreamLevel(enc.get(), 10));
   EXPECT_EQ(JXL_ENC_SUCCESS, JxlEncoderSetBasicInfo(enc.get(), &basic_info));
   JxlColorEncoding color_encoding;
-  JxlColorEncodingSetToSRGB(&color_encoding, /*is_gray=*/false);
+  JxlColorEncodingSetToSRGB(&color_encoding, /*is_gray=*/JXL_FALSE);
   EXPECT_EQ(JXL_ENC_SUCCESS,
             JxlEncoderSetColorEncoding(enc.get(), &color_encoding));
 
@@ -1158,7 +1159,7 @@ TEST(EncodeTest, AnimationHeaderTest) {
   EXPECT_NE(nullptr, enc.get());
 
   JxlEncoderFrameSettings* frame_settings =
-      JxlEncoderFrameSettingsCreate(enc.get(), NULL);
+      JxlEncoderFrameSettingsCreate(enc.get(), nullptr);
   size_t xsize = 1;
   size_t ysize = 1;
   JxlPixelFormat pixel_format = {4, JXL_TYPE_UINT16, JXL_BIG_ENDIAN, 0};
@@ -1167,14 +1168,14 @@ TEST(EncodeTest, AnimationHeaderTest) {
   jxl::test::JxlBasicInfoSetFromPixelFormat(&basic_info, &pixel_format);
   basic_info.xsize = xsize;
   basic_info.ysize = ysize;
-  basic_info.have_animation = true;
+  basic_info.have_animation = JXL_TRUE;
   basic_info.animation.tps_numerator = 1000;
   basic_info.animation.tps_denominator = 1;
   basic_info.animation.have_timecodes = JXL_TRUE;
   EXPECT_EQ(JXL_ENC_SUCCESS, JxlEncoderSetCodestreamLevel(enc.get(), 10));
   EXPECT_EQ(JXL_ENC_SUCCESS, JxlEncoderSetBasicInfo(enc.get(), &basic_info));
   JxlColorEncoding color_encoding;
-  JxlColorEncodingSetToSRGB(&color_encoding, /*is_gray=*/false);
+  JxlColorEncodingSetToSRGB(&color_encoding, /*is_gray=*/JXL_FALSE);
   EXPECT_EQ(JXL_ENC_SUCCESS,
             JxlEncoderSetColorEncoding(enc.get(), &color_encoding));
 
@@ -1261,7 +1262,7 @@ TEST(EncodeTest, CroppedFrameTest) {
   EXPECT_NE(nullptr, enc.get());
 
   JxlEncoderFrameSettings* frame_settings =
-      JxlEncoderFrameSettingsCreate(enc.get(), NULL);
+      JxlEncoderFrameSettingsCreate(enc.get(), nullptr);
   size_t xsize = 300;
   size_t ysize = 300;
   JxlPixelFormat pixel_format = {4, JXL_TYPE_UINT16, JXL_BIG_ENDIAN, 0};
@@ -1276,7 +1277,7 @@ TEST(EncodeTest, CroppedFrameTest) {
   EXPECT_EQ(JXL_ENC_SUCCESS, JxlEncoderSetCodestreamLevel(enc.get(), 10));
   EXPECT_EQ(JXL_ENC_SUCCESS, JxlEncoderSetBasicInfo(enc.get(), &basic_info));
   JxlColorEncoding color_encoding;
-  JxlColorEncodingSetToSRGB(&color_encoding, /*is_gray=*/false);
+  JxlColorEncodingSetToSRGB(&color_encoding, /*is_gray=*/JXL_FALSE);
   EXPECT_EQ(JXL_ENC_SUCCESS,
             JxlEncoderSetColorEncoding(enc.get(), &color_encoding));
 
@@ -1345,7 +1346,7 @@ TEST(EncodeTest, CroppedFrameTest) {
 struct EncodeBoxTest : public testing::TestWithParam<std::tuple<bool, size_t>> {
 };
 
-TEST_P(EncodeBoxTest, JXL_BOXES_TEST(BoxTest)) {
+JXL_BOXES_TEST_P(EncodeBoxTest, BoxTest) {
   // Test with uncompressed boxes and with brob boxes
   bool compress_box = std::get<0>(GetParam());
   size_t xml_box_size = std::get<1>(GetParam());
@@ -1361,7 +1362,7 @@ TEST_P(EncodeBoxTest, JXL_BOXES_TEST(BoxTest)) {
   EXPECT_EQ(JXL_ENC_SUCCESS, JxlEncoderUseBoxes(enc.get()));
 
   JxlEncoderFrameSettings* frame_settings =
-      JxlEncoderFrameSettingsCreate(enc.get(), NULL);
+      JxlEncoderFrameSettingsCreate(enc.get(), nullptr);
   size_t xsize = 50;
   size_t ysize = 17;
   JxlPixelFormat pixel_format = {4, JXL_TYPE_UINT16, JXL_BIG_ENDIAN, 0};
@@ -1370,12 +1371,12 @@ TEST_P(EncodeBoxTest, JXL_BOXES_TEST(BoxTest)) {
   jxl::test::JxlBasicInfoSetFromPixelFormat(&basic_info, &pixel_format);
   basic_info.xsize = xsize;
   basic_info.ysize = ysize;
-  basic_info.uses_original_profile = false;
+  basic_info.uses_original_profile = JXL_FALSE;
   EXPECT_EQ(JXL_ENC_SUCCESS, JxlEncoderSetCodestreamLevel(enc.get(), 10));
   EXPECT_EQ(JXL_ENC_SUCCESS, JxlEncoderSetBasicInfo(enc.get(), &basic_info));
   JxlColorEncoding color_encoding;
   JxlColorEncodingSetToSRGB(&color_encoding,
-                            /*is_gray=*/false);
+                            /*is_gray=*/JXL_FALSE);
   EXPECT_EQ(JXL_ENC_SUCCESS,
             JxlEncoderSetColorEncoding(enc.get(), &color_encoding));
 
@@ -1389,7 +1390,8 @@ TEST_P(EncodeBoxTest, JXL_BOXES_TEST(BoxTest)) {
   const uint8_t* exif_data = reinterpret_cast<const uint8_t*>(exif_test_string);
   // Skip the 4 zeroes for strlen
   const size_t exif_size = 4 + strlen(exif_test_string + 4);
-  JxlEncoderAddBox(enc.get(), "Exif", exif_data, exif_size, compress_box);
+  JxlEncoderAddBox(enc.get(), "Exif", exif_data, exif_size,
+                   TO_JXL_BOOL(compress_box));
 
   // Write to output
   ProcessEncoder(enc.get(), compressed, next_out, avail_out);
@@ -1408,7 +1410,8 @@ TEST_P(EncodeBoxTest, JXL_BOXES_TEST(BoxTest)) {
   constexpr const char* xml_test_string = "<some random xml data>";
   const uint8_t* xml_data = reinterpret_cast<const uint8_t*>(xml_test_string);
   size_t xml_size = strlen(xml_test_string);
-  JxlEncoderAddBox(enc.get(), "XML ", xml_data, xml_size, compress_box);
+  JxlEncoderAddBox(enc.get(), "XML ", xml_data, xml_size,
+                   TO_JXL_BOOL(compress_box));
 
   // Indicate this is the last box
   JxlEncoderCloseBoxes(enc.get());
@@ -1450,12 +1453,12 @@ TEST_P(EncodeBoxTest, JXL_BOXES_TEST(BoxTest)) {
       EXPECT_EQ(0, JxlDecoderReleaseBoxBuffer(dec.get()));
       JxlBoxType type;
       EXPECT_EQ(JXL_DEC_SUCCESS, JxlDecoderGetBoxType(dec.get(), type, true));
-      if (!memcmp(type, "Exif", 4)) {
+      if (memcmp(type, "Exif", 4) == 0) {
         // This box should have been encoded before the image frame
         EXPECT_EQ(false, post_frame);
         JxlDecoderSetBoxBuffer(dec.get(), dec_exif_box.data(),
                                dec_exif_box.size());
-      } else if (!memcmp(type, "XML ", 4)) {
+      } else if (memcmp(type, "XML ", 4) == 0) {
         // This box should have been encoded after the image frame
         EXPECT_EQ(true, post_frame);
         JxlDecoderSetBoxBuffer(dec.get(), dec_xml_box.data(),
@@ -1483,8 +1486,9 @@ JXL_GTEST_INSTANTIATE_TEST_SUITE_P(
                                      jxl::kLargeBoxContentSizeThreshold + 77)),
     nameBoxTest);
 
-TEST(EncodeTest, JXL_TRANSCODE_JPEG_TEST(JPEGFrameTest)) {
+JXL_TRANSCODE_JPEG_TEST(EncodeTest, JPEGFrameTest) {
   TEST_LIBJPEG_SUPPORT();
+  JxlMemoryManager* memory_manager = jxl::test::MemoryManager();
   for (int skip_basic_info = 0; skip_basic_info < 2; skip_basic_info++) {
     for (int skip_color_encoding = 0; skip_color_encoding < 2;
          skip_color_encoding++) {
@@ -1492,13 +1496,13 @@ TEST(EncodeTest, JXL_TRANSCODE_JPEG_TEST(JPEGFrameTest)) {
       if (skip_basic_info && !skip_color_encoding) continue;
       const std::string jpeg_path = "jxl/flower/flower_cropped.jpg";
       const std::vector<uint8_t> orig = jxl::test::ReadTestData(jpeg_path);
-      jxl::CodecInOut orig_io;
+      jxl::CodecInOut orig_io{memory_manager};
       ASSERT_TRUE(SetFromBytes(jxl::Bytes(orig), &orig_io,
                                /*pool=*/nullptr));
 
       JxlEncoderPtr enc = JxlEncoderMake(nullptr);
       JxlEncoderFrameSettings* frame_settings =
-          JxlEncoderFrameSettingsCreate(enc.get(), NULL);
+          JxlEncoderFrameSettingsCreate(enc.get(), nullptr);
       JxlEncoderFrameSettingsSetOption(frame_settings,
                                        JXL_ENC_FRAME_SETTING_EFFORT, 1);
       if (!skip_basic_info) {
@@ -1506,13 +1510,13 @@ TEST(EncodeTest, JXL_TRANSCODE_JPEG_TEST(JPEGFrameTest)) {
         JxlEncoderInitBasicInfo(&basic_info);
         basic_info.xsize = orig_io.xsize();
         basic_info.ysize = orig_io.ysize();
-        basic_info.uses_original_profile = true;
+        basic_info.uses_original_profile = JXL_TRUE;
         EXPECT_EQ(JXL_ENC_SUCCESS,
                   JxlEncoderSetBasicInfo(enc.get(), &basic_info));
       }
       if (!skip_color_encoding) {
         JxlColorEncoding color_encoding;
-        JxlColorEncodingSetToSRGB(&color_encoding, /*is_gray=*/false);
+        JxlColorEncodingSetToSRGB(&color_encoding, /*is_gray=*/JXL_FALSE);
         EXPECT_EQ(JXL_ENC_SUCCESS,
                   JxlEncoderSetColorEncoding(enc.get(), &color_encoding));
       }
@@ -1537,7 +1541,7 @@ TEST(EncodeTest, JXL_TRANSCODE_JPEG_TEST(JPEGFrameTest)) {
       compressed.resize(next_out - compressed.data());
       EXPECT_EQ(JXL_ENC_SUCCESS, process_result);
 
-      jxl::CodecInOut decoded_io;
+      jxl::CodecInOut decoded_io{memory_manager};
       EXPECT_TRUE(jxl::test::DecodeFile(
           {}, jxl::Bytes(compressed.data(), compressed.size()), &decoded_io));
 
@@ -1699,14 +1703,16 @@ class JxlChunkedFrameInputSourceAdapter {
 
 struct StreamingTestParam {
   size_t bitmask;
-  bool use_container() const { return bitmask & 0x1; }
-  bool return_large_buffers() const { return bitmask & 0x2; }
-  bool multiple_frames() const { return bitmask & 0x4; }
-  bool fast_lossless() const { return bitmask & 0x8; }
-  bool can_seek() const { return bitmask & 0x10; }
-  bool with_extra_channels() const { return bitmask & 0x20; }
-  bool color_includes_alpha() const { return bitmask & 0x40; }
-  bool onegroup() const { return bitmask & 0x80; }
+  bool use_container() const { return static_cast<bool>(bitmask & 0x1); }
+  bool return_large_buffers() const { return static_cast<bool>(bitmask & 0x2); }
+  bool multiple_frames() const { return static_cast<bool>(bitmask & 0x4); }
+  bool fast_lossless() const { return static_cast<bool>(bitmask & 0x8); }
+  bool can_seek() const { return static_cast<bool>(bitmask & 0x10); }
+  bool with_extra_channels() const { return static_cast<bool>(bitmask & 0x20); }
+  bool color_includes_alpha() const {
+    return static_cast<bool>(bitmask & 0x40);
+  }
+  bool onegroup() const { return static_cast<bool>(bitmask & 0x80); }
 
   bool is_lossless() const { return fast_lossless(); }
 
@@ -1762,22 +1768,24 @@ class EncoderStreamingTest : public testing::TestWithParam<StreamingTestParam> {
   static void SetupImage(const StreamingTestParam& p, size_t xsize,
                          size_t ysize, size_t num_channels,
                          size_t bits_per_sample, jxl::test::TestImage& image) {
-    image.SetDimensions(xsize, ysize)
-        .SetDataType(JXL_TYPE_UINT8)
-        .SetChannels(num_channels)
-        .SetAllBitDepths(bits_per_sample);
+    ASSERT_TRUE(image.SetDimensions(xsize, ysize));
+    image.SetDataType(JXL_TYPE_UINT8);
+    ASSERT_TRUE(image.SetChannels(num_channels));
+    image.SetAllBitDepths(bits_per_sample);
     if (p.onegroup()) {
       image.SetRowAlignment(128);
     }
-    image.AddFrame().RandomFill();
+    JXL_TEST_ASSIGN_OR_DIE(auto frame, image.AddFrame());
+    frame.RandomFill();
   }
   static void SetUpBasicInfo(JxlBasicInfo& basic_info, size_t xsize,
                              size_t ysize, size_t number_extra_channels,
                              bool include_alpha, bool is_lossless) {
     basic_info.xsize = xsize;
     basic_info.ysize = ysize;
-    basic_info.num_extra_channels = number_extra_channels + include_alpha;
-    basic_info.uses_original_profile = is_lossless;
+    basic_info.num_extra_channels =
+        number_extra_channels + (include_alpha ? 1 : 0);
+    basic_info.uses_original_profile = TO_JXL_BOOL(is_lossless);
   }
 
   static void SetupEncoder(JxlEncoderFrameSettings* frame_settings,
@@ -1794,7 +1802,7 @@ class EncoderStreamingTest : public testing::TestWithParam<StreamingTestParam> {
                     frame_settings, JXL_ENC_FRAME_SETTING_EFFORT, 1));
     }
     JxlColorEncoding color_encoding;
-    JxlColorEncodingSetToSRGB(&color_encoding, /*is_gray=*/false);
+    JxlColorEncodingSetToSRGB(&color_encoding, /*is_gray=*/JXL_FALSE);
     EXPECT_EQ(JXL_ENC_SUCCESS,
               JxlEncoderSetColorEncoding(enc, &color_encoding));
     EXPECT_EQ(JXL_ENC_SUCCESS,
@@ -1828,7 +1836,7 @@ class EncoderStreamingTest : public testing::TestWithParam<StreamingTestParam> {
         // Copy pixel data here because it is only guaranteed to be available
         // during the call to JxlEncoderAddImageFrame().
         std::vector<uint8_t> pixels(frame.pixels_size);
-        memcpy(&pixels[0], frame.pixels(), pixels.size());
+        memcpy(pixels.data(), frame.pixels(), pixels.size());
         EXPECT_EQ(JXL_ENC_SUCCESS,
                   JxlEncoderAddImageFrame(frame_settings, &frame.format,
                                           pixels.data(), pixels.size()));
@@ -1837,7 +1845,7 @@ class EncoderStreamingTest : public testing::TestWithParam<StreamingTestParam> {
         // Copy pixel data here because it is only guaranteed to be available
         // during the call to JxlEncoderSetExtraChannelBuffer().
         std::vector<uint8_t> ec_pixels(ec_frame.pixels_size);
-        memcpy(&ec_pixels[0], ec_frame.pixels(), ec_pixels.size());
+        memcpy(ec_pixels.data(), ec_frame.pixels(), ec_pixels.size());
         EXPECT_EQ(JXL_ENC_SUCCESS, JxlEncoderSetExtraChannelBuffer(
                                        frame_settings, &ec_frame.format,
                                        ec_pixels.data(), ec_pixels.size(), i));
@@ -1883,12 +1891,12 @@ TEST_P(EncoderStreamingTest, OutputCallback) {
                  p.color_includes_alpha(), p.is_lossless());
 
   std::vector<uint8_t> compressed = std::vector<uint8_t>(64);
-  // without sreaming
+  // without streaming
   {
     JxlEncoderPtr enc = JxlEncoderMake(nullptr);
     ASSERT_NE(nullptr, enc.get());
     JxlEncoderFrameSettings* frame_settings =
-        JxlEncoderFrameSettingsCreate(enc.get(), NULL);
+        JxlEncoderFrameSettingsCreate(enc.get(), nullptr);
     SetupEncoder(frame_settings, p, basic_info, number_extra_channels, false);
     SetupInputNonStreaming(frame_settings, p, number_extra_channels, frame,
                            ec_frame);
@@ -1903,7 +1911,7 @@ TEST_P(EncoderStreamingTest, OutputCallback) {
     JxlEncoderPtr enc = JxlEncoderMake(nullptr);
     ASSERT_NE(nullptr, enc.get());
     JxlEncoderFrameSettings* frame_settings =
-        JxlEncoderFrameSettingsCreate(enc.get(), NULL);
+        JxlEncoderFrameSettingsCreate(enc.get(), nullptr);
     SetupEncoder(frame_settings, p, basic_info, number_extra_channels, true);
     SetupInputNonStreaming(frame_settings, p, number_extra_channels, frame,
                            ec_frame);
@@ -1941,7 +1949,7 @@ TEST_P(EncoderStreamingTest, ChunkedFrame) {
     JxlEncoderPtr enc = JxlEncoderMake(nullptr);
     ASSERT_NE(nullptr, enc.get());
     JxlEncoderFrameSettings* frame_settings =
-        JxlEncoderFrameSettingsCreate(enc.get(), NULL);
+        JxlEncoderFrameSettingsCreate(enc.get(), nullptr);
     SetupEncoder(frame_settings, p, basic_info, number_extra_channels, false);
     SetupInputNonStreaming(frame_settings, p, number_extra_channels, frame,
                            ec_frame);
@@ -1955,7 +1963,7 @@ TEST_P(EncoderStreamingTest, ChunkedFrame) {
     JxlEncoderPtr enc = JxlEncoderMake(nullptr);
     ASSERT_NE(nullptr, enc.get());
     JxlEncoderFrameSettings* frame_settings =
-        JxlEncoderFrameSettingsCreate(enc.get(), NULL);
+        JxlEncoderFrameSettingsCreate(enc.get(), nullptr);
     SetupEncoder(frame_settings, p, basic_info, number_extra_channels, true);
     SetupInputStreaming(frame_settings, p, number_extra_channels, frame,
                         ec_frame);
@@ -1991,7 +1999,7 @@ TEST_P(EncoderStreamingTest, ChunkedAndOutputCallback) {
     JxlEncoderPtr enc = JxlEncoderMake(nullptr);
     ASSERT_NE(nullptr, enc.get());
     JxlEncoderFrameSettings* frame_settings =
-        JxlEncoderFrameSettingsCreate(enc.get(), NULL);
+        JxlEncoderFrameSettingsCreate(enc.get(), nullptr);
     SetupEncoder(frame_settings, p, basic_info, number_extra_channels, false);
     SetupInputNonStreaming(frame_settings, p, number_extra_channels, frame,
                            ec_frame);
@@ -2006,7 +2014,7 @@ TEST_P(EncoderStreamingTest, ChunkedAndOutputCallback) {
     JxlEncoderPtr enc = JxlEncoderMake(nullptr);
     ASSERT_NE(nullptr, enc.get());
     JxlEncoderFrameSettings* frame_settings =
-        JxlEncoderFrameSettingsCreate(enc.get(), NULL);
+        JxlEncoderFrameSettingsCreate(enc.get(), nullptr);
     SetupEncoder(frame_settings, p, basic_info, number_extra_channels, true);
     JxlStreamingAdapter streaming_adapter =
         JxlStreamingAdapter(enc.get(), p.return_large_buffers(), p.can_seek());
@@ -2028,17 +2036,19 @@ TEST(EncoderTest, CMYK) {
   size_t xsize = 257;
   size_t ysize = 259;
   jxl::test::TestImage image;
-  image.SetDimensions(xsize, ysize)
-      .SetDataType(JXL_TYPE_UINT8)
-      .SetChannels(3)
-      .SetAllBitDepths(8);
-  image.AddFrame().RandomFill();
+  ASSERT_TRUE(image.SetDimensions(xsize, ysize));
+  image.SetDataType(JXL_TYPE_UINT8);
+  ASSERT_TRUE(image.SetChannels(3));
+  image.SetAllBitDepths(8);
+  JXL_TEST_ASSIGN_OR_DIE(auto frame0, image.AddFrame());
+  frame0.RandomFill();
   jxl::test::TestImage ec_image;
-  ec_image.SetDataType(JXL_TYPE_UINT8)
-      .SetDimensions(xsize, ysize)
-      .SetChannels(1)
-      .SetAllBitDepths(8);
-  ec_image.AddFrame().RandomFill();
+  ec_image.SetDataType(JXL_TYPE_UINT8);
+  ASSERT_TRUE(ec_image.SetDimensions(xsize, ysize));
+  ASSERT_TRUE(ec_image.SetChannels(1));
+  ec_image.SetAllBitDepths(8);
+  JXL_TEST_ASSIGN_OR_DIE(auto frame1, ec_image.AddFrame());
+  frame1.RandomFill();
   const auto& frame = image.ppf().frames[0].color;
   const auto& ec_frame = ec_image.ppf().frames[0].color;
   JxlBasicInfo basic_info = image.ppf().info;
@@ -2052,7 +2062,7 @@ TEST(EncoderTest, CMYK) {
   JxlEncoderStruct* enc = enc_ptr.get();
   ASSERT_NE(nullptr, enc);
   JxlEncoderFrameSettings* frame_settings =
-      JxlEncoderFrameSettingsCreate(enc, NULL);
+      JxlEncoderFrameSettingsCreate(enc, nullptr);
 
   EXPECT_EQ(JXL_ENC_SUCCESS, JxlEncoderSetBasicInfo(enc, &basic_info));
   JxlExtraChannelInfo channel_info;
